@@ -4,7 +4,6 @@
     Only support 9.x version.
     Start from 9.0, Portal SOAP API needs Bear Token for authentication
 """
-import base64
 from os.path import exists
 
 from .zeepClient import get_client_and_factory, retry_when_unauthorized
@@ -384,6 +383,56 @@ def export_queries(queries_ids):
     }
 
 
+def get_compare_scan_results(old_scan_id, new_scan_id):
+    """
+
+    Args:
+        old_scan_id (int):
+        new_scan_id (int):
+
+    Returns:
+
+    """
+
+    @retry_when_unauthorized
+    def execute():
+        client, _ = get_client_and_factory(relative_web_interface_url=relative_web_interface_url)
+        return client.service.GetCompareScanResults(sessionId="0", oldScanId=old_scan_id, newScanId=new_scan_id)
+
+    response = execute()
+    return {
+        "IsSuccesfull": response["IsSuccesfull"],
+        "ErrorMessage": response["ErrorMessage"],
+        "Results": [
+            {
+                'QueryId': item.QueryId,
+                'PathId': item.PathId,
+                'SourceFolder': item.SourceFolder,
+                'SourceFile': item.SourceFile,
+                'SourceLine': item.SourceLine,
+                'SourceObject': item.SourceObject,
+                'DestFolder': item.DestFolder,
+                'DestFile': item.DestFile,
+                'DestLine': item.DestLine,
+                'NumberOfNodes': item.NumberOfNodes,
+                'DestObject': item.DestObject,
+                'Comment': item.Comment,
+                'State': item.State,
+                'Severity': item.Severity,
+                'AssignedUser': item.AssignedUser,
+                'ConfidenceLevel': item.ConfidenceLevel,
+                'ResultStatus': item.ResultStatus,
+                'IssueTicketID': item.IssueTicketID,
+                'QueryVersionCode': item.QueryVersionCode,
+                'ScanId': item.ScanId,
+                'ComparedToScanId': item.ComparedToScanId,
+                'ComparedToScanPathId': item.ComparedToScanPathId,
+                'QueryName': item.QueryName,
+            } for item in response["Results"]["CxWSSingleResultCompareData"]
+        ]
+    }
+
+
 def get_import_queries_status(request_id):
     """
 
@@ -654,6 +703,98 @@ def get_preset_list():
     }
 
 
+def get_result_path(scan_id, path_id):
+    """
+
+    Args:
+        scan_id (int):
+        path_id (int):
+
+    Returns:
+
+    """
+
+    @retry_when_unauthorized
+    def execute():
+        client, factory = get_client_and_factory(relative_web_interface_url=relative_web_interface_url)
+        return client.service.GetResultPath(sessionId="0", scanId=scan_id, pathId=path_id)
+
+    response = execute()
+    item = response.Path
+    return {
+        "IsSuccesfull": response["IsSuccesfull"],
+        "ErrorMessage": response["ErrorMessage"],
+        "Path": {
+            "AssignedUser": item["AssignedUser"],
+            "Comment": item["Comment"],
+            "PathId": item["PathId"],
+            "Severity": item["Severity"],
+            "SimilarityId": item["SimilarityId"],
+            "State": item["State"],
+            "Nodes": [
+                {
+                    "Column": node["Column"],
+                    "DOM_Id": node["DOM_Id"],
+                    "FileName": node["FileName"],
+                    "FullName": node["FullName"],
+                    "Length": node["Length"],
+                    "Line": node["Line"],
+                    "MethodLine": node["MethodLine"],
+                    "Name": node["Name"],
+                    "PathNodeId": node["PathNodeId"],
+                }
+                for node in item["Nodes"]["CxWSPathNode"]
+            ],
+        }
+    }
+
+
+def get_results_for_scan(scan_id):
+    """
+
+    Args:
+        scan_id (int):
+
+    Returns:
+
+    """
+
+    @retry_when_unauthorized
+    def execute():
+        client, factory = get_client_and_factory(relative_web_interface_url=relative_web_interface_url)
+        return client.service.GetResultsForScan(sessionID="0", scanId=scan_id)
+
+    response = execute()
+    scan_results_list = response.Results.CxWSSingleResultData
+    return {
+        "IsSuccesfull": response["IsSuccesfull"],
+        "ErrorMessage": response["ErrorMessage"],
+        "ScanResults": [
+            {
+                "QueryId": item["QueryId"],
+                "PathId": item["PathId"],
+                "SourceFolder": item["SourceFolder"],
+                "SourceFile": item["SourceFile"],
+                "SourceLine": item["SourceLine"],
+                "SourceObject": item["SourceObject"],
+                "DestFolder": item["DestFolder"],
+                "DestFile": item["DestFile"],
+                "DestLine": item["DestLine"],
+                "NumberOfNodes": item["NumberOfNodes"],
+                "DestObject": item["DestObject"],
+                "Comment": item["Comment"],
+                "State": item["State"],
+                "Severity": item["Severity"],
+                "AssignedUser": item["AssignedUser"],
+                "ConfidenceLevel": item["ConfidenceLevel"],
+                "ResultStatus": item["ResultStatus"],
+                "IssueTicketID": item["IssueTicketID"],
+                "QueryVersionCode": item["QueryVersionCode"],
+            } for item in scan_results_list
+        ] if scan_results_list else None
+    }
+
+
 def get_server_license_data():
     """
 
